Skip to content
Snippets Groups Projects
Commit 9429b899 authored by Bernhard Rosenkränzer's avatar Bernhard Rosenkränzer
Browse files

gcc: Update to 12.1.0 final, rebase patches


Signed-off-by: default avatarBernhard Rosenkränzer <bernhard.rosenkraenzer.ext@huawei.com>
parent b0df9137
No related branches found
No related tags found
1 merge request!109gcc: Update to 12.1.0 final, rebase patches
Showing
with 15 additions and 15 deletions
...@@ -2,14 +2,14 @@ require gcc-common.inc ...@@ -2,14 +2,14 @@ require gcc-common.inc
# Third digit in PV should be incremented after a minor release # Third digit in PV should be incremented after a minor release
PV = "12.0.1" PV = "12.1.0"
# BINV should be incremented to a revision after a minor gcc release # BINV should be incremented to a revision after a minor gcc release
BINV = "12.0.1" BINV = "12.1.0"
MAJOR = "12" MAJOR = "12"
SNAPSHOT = "20220313" # SNAPSHOT = "20220313"
FILESEXTRAPATHS =. "${FILE_DIRNAME}/gcc:${FILE_DIRNAME}/gcc/backport:" FILESEXTRAPATHS =. "${FILE_DIRNAME}/gcc:${FILE_DIRNAME}/gcc/backport:"
...@@ -26,11 +26,11 @@ LIC_FILES_CHKSUM = "\ ...@@ -26,11 +26,11 @@ LIC_FILES_CHKSUM = "\
file://COPYING.RUNTIME;md5=fe60d87048567d4fe8c8a0ed2448bcc8 \ file://COPYING.RUNTIME;md5=fe60d87048567d4fe8c8a0ed2448bcc8 \
" "
#RELEASE ?= "5b2ac9b40c325e9209c0bd55955db84aad4a0cc5" RELEASE ?= "1ea978e3066ac565a1ec28a96a4d61eaf38e2726"
#BASEURI ?= "https://github.com/gcc-mirror/gcc/archive/${RELEASE}.zip;downloadfilename=gcc-${PV}-${RELEASE}.zip" BASEURI ?= "https://github.com/gcc-mirror/gcc/archive/${RELEASE}.tar.gz;downloadfilename=gcc-${PV}-${RELEASE}.tar.gz"
BASEURI ?= "https://mirror.koddos.net/gcc/snapshots/${MAJOR}-${SNAPSHOT}/gcc-${MAJOR}-${SNAPSHOT}.tar.xz \ # For snapshots
" #BASEURI ?= "https://mirror.koddos.net/gcc/snapshots/${MAJOR}-${SNAPSHOT}/gcc-${MAJOR}-${SNAPSHOT}.tar.xz"
SRC_URI = "\ SRC_URI = "\
${BASEURI} \ ${BASEURI} \
file://0001-gcc-4.3.1-ARCH_FLAGS_FOR_TARGET.patch \ file://0001-gcc-4.3.1-ARCH_FLAGS_FOR_TARGET.patch \
...@@ -57,12 +57,12 @@ SRC_URI = "\ ...@@ -57,12 +57,12 @@ SRC_URI = "\
file://0006-If-CXXFLAGS-contains-something-unsupported-by-the-bu.patch \ file://0006-If-CXXFLAGS-contains-something-unsupported-by-the-bu.patch \
file://0001-Fix-install-path-of-linux64.h.patch \ file://0001-Fix-install-path-of-linux64.h.patch \
" "
SRC_URI[sha256sum] = "979d8cbe9b2ed2ab4434f52097754e004a207cf6541aea3e167c5d0f74957633" SRC_URI[sha256sum] = "37f4815d27485cd84bfd725598a5afe53714ce4ecdfdef4bc266c086ae165367"
S = "${TMPDIR}/work-shared/gcc-${PV}-${PR}/gcc-${MAJOR}-${SNAPSHOT}" S = "${TMPDIR}/work-shared/gcc-${PV}-${PR}/gcc-${RELEASE}"
# For dev release snapshotting # For dev release snapshotting
#S = "${TMPDIR}/work-shared/gcc-${PV}-${PR}/gcc-${RELEASE}" #S = "${TMPDIR}/work-shared/gcc-${PV}-${PR}/gcc-${MAJOR}-${SNAPSHOT}"
#B = "${WORKDIR}/gcc-${PV}/build.${HOST_SYS}.${TARGET_SYS}" #B = "${WORKDIR}/gcc-${PV}/build.${HOST_SYS}.${TARGET_SYS}"
# Language Overrides # Language Overrides
......
...@@ -43,17 +43,17 @@ diff --git a/gcc/config/i386/i386-expand.cc b/gcc/config/i386/i386-expand.cc ...@@ -43,17 +43,17 @@ diff --git a/gcc/config/i386/i386-expand.cc b/gcc/config/i386/i386-expand.cc
index ac69eed4d32..ffaa44a16fc 100644 index ac69eed4d32..ffaa44a16fc 100644
--- a/gcc/config/i386/i386-expand.cc --- a/gcc/config/i386/i386-expand.cc
+++ b/gcc/config/i386/i386-expand.cc +++ b/gcc/config/i386/i386-expand.cc
@@ -11038,10 +11038,10 @@ ix86_expand_builtin (tree exp, rtx target, rtx subtarget, @@ -12338,10 +12338,10 @@ ix86_expand_builtin (tree exp, rtx targe
{ {
case IX86_BUILTIN_CPU_INIT: case IX86_BUILTIN_CPU_INIT:
{ {
/* Make it call __cpu_indicator_init in libgcc. */ - /* Make it call __cpu_indicator_init in libgcc. */
tree call_expr, fndecl, type; tree call_expr, fndecl, type;
type = build_function_type_list (integer_type_node, NULL_TREE); type = build_function_type_list (integer_type_node, NULL_TREE);
- fndecl = build_fn_decl ("__cpu_indicator_init", type); - fndecl = build_fn_decl ("__cpu_indicator_init", type);
+ fndecl = build_fn_decl ("__cpu_indicator_init_local", type); + fndecl = build_fn_decl ("__cpu_indicator_init_local", type);
call_expr = build_call_expr (fndecl, 0); call_expr = build_call_expr (fndecl, 0);
return expand_expr (call_expr, target, mode, EXPAND_NORMAL); return expand_expr (call_expr, target, mode, EXPAND_NORMAL);
} }
@@ -11038,10 +11038,10 @@ ix86_expand_builtin (tree exp, rtx target, rtx subtarget, @@ -12338,10 +12338,10 @@ ix86_expand_builtin (tree exp, rtx targe
case IX86_BUILTIN_CPU_INIT: case IX86_BUILTIN_CPU_INIT:
{ {
- /* Make it call __cpu_indicator_init in libgcc. */ - /* Make it call __cpu_indicator_init in libgcc. */
+ /* Make it call __cpu_indicator_init_local in libgcc.a. */ + /* Make it call __cpu_indicator_init_local in libgcc.a. */
tree call_expr, fndecl, type; tree call_expr, fndecl, type;
type = build_function_type_list (integer_type_node, NULL_TREE); type = build_function_type_list (integer_type_node, NULL_TREE);
diff --git a/libgcc/config/i386/cpuinfo.c b/libgcc/config/i386/cpuinfo.c diff --git a/libgcc/config/i386/cpuinfo.c b/libgcc/config/i386/cpuinfo.c
......
0% Loading or .
You are about to add 0 people to the discussion. Proceed with caution.
Finish editing this message first!
Please register or to comment